import { Logging } from "./logging"

export interface rejectionError {
  message: string
  statusCode: number
  solved: boolean
  type?: Logging[]
}
interface rejectionErrors {
  [key: string]: rejectionError
}

export const rejectionErrors: rejectionErrors = {
  noCookie: {
    message: "Unauthorized. No cookie.",
    statusCode: 401,
    solved: true,
  },
  noBody: {
    message: "Unauthorized. No Body.",
    statusCode: 401,
    solved: true,
    type: ["warn"],
  },
  noUsername: {
    message: "No username in request body!",
    statusCode: 401,
    solved: true,
    type: ["warn"],
  },
  noPassword: {
    message: "No password in request body!",
    statusCode: 401,
    solved: true,
    type: ["warn"],
  },
  wrongPassword: {
    message: "Passwords do not match!",
    statusCode: 401,
    solved: true,
    type: ["warn"],
  },
  playerNotFound: {
    message: "Player name not found in DB!",
    statusCode: 401,
    solved: false,
    type: ["warn"],
  },
  tokenUsed: {
    message: "DBToken was already used!",
    statusCode: 401,
    solved: true,
    type: ["warn"],
  },
  registered: {
    message: "Player is already registered!",
    statusCode: 403,
    solved: true,
    type: ["warn"],
  },
  gameNotFound: {
    message: "Game not found!",
    statusCode: 403,
    solved: true,
  },
  unauthorized: {
    message: "Unauthorized",
    statusCode: 401,
    solved: true,
  },
}
