import { authOptions } from "../auth/[...nextauth]"
import sendResponse from "@backend/sendResponse"
import prisma from "@lib/prisma"
import { createSchema } from "@lib/zodSchemas"
import type { NextApiRequest, NextApiResponse } from "next"
import { getServerSession } from "next-auth"
import { z } from "zod"

type Data = z.infer<typeof createSchema>

export default async function create(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const session = await getServerSession(req, res, authOptions)

  if (!session) {
    return sendResponse(req, res, {
      message: "Unauthorized",
      statusCode: 401,
      type: ["error"],
    })
  }

  if (!session.user) {
    return sendResponse(req, res, {
      message: "Unauthorized - No User",
      statusCode: 401,
      type: ["error"],
    })
  }
  const { email, id, name } = session.user

  // Generate a random 4-digit code
  const pin = Math.floor(Math.random() * 10000)
    .toString()
    .padStart(4, "0")

  let created = false

  let game = await prisma.game.findFirst({
    where: {
      running: true,
      users: {
        some: {
          userId: id,
        },
      },
    },
    include: {
      gamePin: true,
      users: true,
    },
  })
  if (!game) {
    created = true
    game = await prisma.game.create({
      data: {
        gamePin: {
          create: {
            pin,
          },
        },
        users: {
          create: {
            isOwner: true,
            userId: id,
          },
        },
      },
      include: {
        gamePin: true,
        users: true,
      },
    })
  }

  return sendResponse(req, res, {
    message: `User <${email}> created game: ${game.id}`,
    statusCode: created ? 201 : 200,
    body: {
      game,
      pin: game.gamePin?.pin,
      player: {
        id,
        name: name ?? undefined,
        isOwner: true,
      },
    },
    type: ["debug", "infoCyan"],
  })
}
